bayespy.inference.vmp.nodes.gaussian.GaussianARDDistribution.__init__
=====================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianARDDistribution.__init__